import 'package:mmoo_base/dao/base_dao.dart';
import 'package:mmoo_base/dao/dao_result.dart';
import 'package:mmoo_base_recharge/dao/recharge_url.dart';
import 'package:mmoo_base_recharge/entity/recharge_entity.dart';
import 'package:mmoo_base_recharge/entity/recharge_list_entity.dart';
import 'package:mmoo_base_recharge/entity/recharge_type_entity.dart';

class RechargeDao {
  ///获取充值列表-支持的充值类型
  static Future<DataResult> rechargeSupport() async {
    var res = await BaseDao.fromBaseJson({}, RechargeUrl.rechargeSupport());
    if (res.result) {
      var entity = RechargeTypeEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  ///获取充值列表 type: 0 充值列表 1 余额不足提醒 2 通话中余额不足倒计时, codeType: 0 PayPal 1 ios 2 google
  static Future<DataResult> rechargeList(String type, String codeType) async {
    Map other = {'type': type, 'codeType': codeType};
    var res = await BaseDao.fromBaseJson(other, RechargeUrl.rechargeList());
    if (res.result) {
      var entity = RechargeListEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  ///充值统一下单
  static Future<DataResult> rechargeOrder(listId) async {
    Map other = {'listId': listId};
    var res = await BaseDao.fromBaseJson(other, RechargeUrl.rechargeOrder());
    if (res.result) {
      var entity = RechargeEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  ///充值ppy检查是否成功
  static Future<DataResult> rechargePpCheck(String? orderId) async {
    Map other = {'orderId': orderId ?? ''};
    var res = await BaseDao.fromBaseJson(other, RechargeUrl.rechargePpCheck());
    if (res.result) {
      var entity = RechargeEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  ///充值内购检查是否成功
  static Future<DataResult> rechargeInCheck(String? token, String? sign,
      {String? productID}) async {
    Map other = {
      'baseStr': token,
      'signature': sign ?? '',
      'code': productID ?? '',
    };
    var res = await BaseDao.fromBaseJson(other, RechargeUrl.rechargeInCheck());
    if (res.result) {
      var entity = RechargeEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  ///充值内购检查是否成功Vip
  static Future<DataResult> rechargeInCheckVip(
      String? token, String? sign, String? orderId,
      {String? productID}) async {
    Map other = {
      'baseStr': token,
      'signature': sign ?? '',
      'orderId': orderId ?? '',
      'code': productID ?? '',
    };
    var res =
        await BaseDao.fromBaseJson(other, RechargeUrl.rechargeInCheckVip());
    if (res.result) {
      var entity = RechargeEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  ///充值取消上报
  static Future<DataResult> rechargeCancel(String? orderId) async {
    Map other = {'orderId': orderId ?? ''};
    var res = await BaseDao.fromBaseJson(other, RechargeUrl.rechargeCancel());
    if (res.result) {
      var entity = RechargeEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  ///充值失败上报
  static Future<DataResult> rechargeFailLog(
      String? token, String? sign, String? orderId, String? errorMsg) async {
    Map other = {
      'baseStr': token,
      'signature': sign ?? '',
      'orderId': orderId ?? '',
      'errorMsg': errorMsg
    };
    var res = await BaseDao.fromBaseJson(other, RechargeUrl.rechargeFailLog());
    if (res.result) {
      var entity = RechargeEntity().fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }
}
